# frozen_string_literal: true

require_relative 'rake/class_definition_in_task'
require_relative 'rake/desc'
require_relative 'rake/duplicate_task'
require_relative 'rake/duplicate_namespace'
require_relative 'rake/method_definition_in_task'
